[![Build Status](https://travis-ci.org/beukueb/leopard.svg?branch=master)](https://travis-ci.org/beukueb/leopard)
[![python-3.6](https://img.shields.io/badge/python-3.6-blue.svg)]()

# leopard

<img title="leopard logo" src="leopard_logo.svg" width="200">

Fast lab reporting python package

## Installation

    pip3 install leopard

### Mac OS X issues

matplotlib may complain about the backend, fix:

    echo "backend: TkAgg" >> ~/.matplotlib/matplotlibrc

